from . import (basemodel, gan, dcgan, wgan_gp, sngan, cgan_pd, ssgan,
               infomax_gan, sagan)
